cosmpy.protos.cosmos.evidence package — cosmpy documentation

# cosmpy.protos.cosmos.evidence package

## Subpackages

- cosmpy.protos.cosmos.evidence.v1beta1 package
  - Submodules
  - cosmpy.protos.cosmos.evidence.v1beta1.evidence_pb2 module
  - cosmpy.protos.cosmos.evidence.v1beta1.evidence_pb2_grpc module
  - cosmpy.protos.cosmos.evidence.v1beta1.genesis_pb2 module
  - cosmpy.protos.cosmos.evidence.v1beta1.genesis_pb2_grpc module
  - cosmpy.protos.cosmos.evidence.v1beta1.query_pb2 module
  - cosmpy.protos.cosmos.evidence.v1beta1.query_pb2_grpc module
  - cosmpy.protos.cosmos.evidence.v1beta1.tx_pb2 module
  - cosmpy.protos.cosmos.evidence.v1beta1.tx_pb2_grpc module
  - Module contents

## Module contents